package ssw.mj;

/**
 * This class provides strings constants for the error messages.
 * 
 * @author AW
 */
public class ErrorStrings {

	private static final String[] names = Token.names;
	
	private static final int
		ident      = Token.ident,
		number     = Token.number,
		charConst  = Token.charConst,
		plus       = Token.plus,
		minus      = Token.minus,
		times      = Token.times,
		slash      = Token.slash,
		rem        = Token.rem,
		eql        = Token.eql,
		neq        = Token.neq,
		gtr        = Token.gtr,
		geq        = Token.geq,
		less       = Token.less,
		leq        = Token.leq,
		and        = Token.and,
		or         = Token.or,
		assign     = Token.assign,
		pplus      = Token.pplus,
		mminus     = Token.mminus,
		semicolon  = Token.semicolon,
		lpar       = Token.lpar,
		lbrace     = Token.lbrace,
		continueKW = Token.continueKW,
		doKW       = Token.doKW,
		ifKW       = Token.ifKW,
		newKW      = Token.newKW,
		printKW    = Token.printKW,
		readKW     = Token.readKW,
		returnKW   = Token.returnKW,
		voidKW     = Token.voidKW,
		whileKW    = Token.whileKW;
	
	public static final String
		//----- messages for syntax errors
			//----- for Scanner
		BIG_NUM           = "number too big for integer constant",
		EMPTY_CHARCONST   = "empty character constant",
		INVALID_CHAR      = "invalid character",
		INVALID_CHARCONST = "invalid character constant",
		MISS_SQUOTE       = "missing ' at end of character constant",
		UNDEF_ESC         = "undefined ESC character sequence",
	
			//----- for Parser
		CONST_DECL        = names[number] + " or " + names[charConst] + " expected",
		DESIGN_FOLLOW     = names[assign] + ", " + names[lpar] + ", " + 
		                    names[pplus] + " or " + names[mminus] + " expected",
		INVALID_DECL      = "invalid global declaration",
		INVALID_FACT      = "invalid start of factor: " + names[ident] + ", " +
		                    names[number] + ", " + names[charConst] + ", " +
		                    names[newKW] + " or " + names[lpar] + " expected",
		INVALID_STAT      = "invalid start of statement: " + names[ident] + ", " + 
		                    names[ifKW]     + ", " + names[whileKW]    + ", " +
		                    names[doKW]     + ", " + names[continueKW] + ", " + 
		                    names[returnKW] + ", " + names[readKW] + ", " + 
		                    names[printKW]  + ", " + names[lbrace] + " or " + 
		                    names[semicolon] + " expected",
		METH_DECL         = names[ident] + " or " + names[voidKW] + " expected",
		NO_EOF            = "end of file expected",
		REL_OP            = "relational operator (" + names[eql] + "," + names[neq] + 
		                    "," + names[gtr] + "," + names[geq] + "," + names[less] + 
		                    "," + names[leq] + ") expected",
		
		//----- messages for semantic errors 
			//----- for Parser
		CONST_TYPE        = "value does not match constant type",
		NO_ARRAY          = "indexed object is not an array",
		NO_CLASS          = "dereferenced object is not a class",
		NO_CLASS_TYPE     = "class type expected",
		NO_MAIN           = "main must be a method",
		NO_PARAMS         = "main method must not have any parameters",
		NO_RETURN         = "return expression required",
		NO_TYPE           = "type expected",
		RETURN_VOID       = "void method must not return a value",
		VOID_MAIN         = "main method must return void",
			//----- for Tab
		DECL_NAME         = "name already declared",
		GLOBALS           = "too many global variables",
		LOCALS            = "too many local variables",
		NO_FIELD          = "no such field",
		NOT_FOUND         = "name not found",
		
		PANIC_MODE        = "PANIC MODE: exit at first error";

}